@@ -2,7 +2,7 @@
  * 
  * Copyright © 2004-2006 Bastien Nocera <hadess@hadess.net>
  * Copyright © 2002 David A. Schleef <ds@schleef.org>
- * Copyright © 2006 Christian Persch
+ * Copyright © 2006, 2007 Christian Persch
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -989,6 +989,11 @@ totemPlugin::IsMimeTypeSupported (const char *mimetype,
 {
 	NS_ENSURE_TRUE (mimetype, PR_FALSE);
 
+	return PR_TRUE;
+
+	/* Disabled for the benefit of:
+	 * http://bugzilla.gnome.org/show_bug.cgi?id=418387 */
+#if 0
 #if defined(TOTEM_NARROWSPACE_PLUGIN) || defined(TOTEM_GMP_PLUGIN) || defined(TOTEM_MULLY_PLUGIN)
 	/* We can always play those image types */
 	if (strcmp (mimetype, "image/jpeg") == 0)
@@ -1036,6 +1041,7 @@ totemPlugin::IsMimeTypeSupported (const char *mimetype,
 	}
 
 	return PR_FALSE;
+#endif
 }
 
 PRBool
@@ -1075,13 +1081,18 @@ totemPlugin::ParseBoolean (const char *key,
 {
 	if (value == NULL || strcmp (value, "") == 0)
 		return default_val;
-	if (g_ascii_strcasecmp (value, "false") == 0
-			|| g_ascii_strcasecmp (value, "0") == 0)
+	if (g_ascii_strcasecmp (value, "false") == 0)
 		return PR_FALSE;
-	if (g_ascii_strcasecmp (value, "true") == 0
-			|| g_ascii_strcasecmp (value, "1") == 0)
+	if (g_ascii_strcasecmp (value, "true") == 0)
 		return PR_TRUE;
 
+        char *endptr = NULL;
+        errno = 0;
+        long num = g_ascii_strtoll (value, &endptr, 0);
+        if (endptr != value && errno == 0) {
+                return num > 0;
+        }
+        
 	D ("Unknown value '%s' for parameter '%s'", value, key);
 
 	return default_val;
@@ -1501,14 +1512,6 @@ totemPlugin::Init (NPMIMEType mimetype,
 {
 	D ("Init mimetype '%s' mode %d", (const char *) mimetype, mode);
 
-	/* Make sure the plugin stays resident, to avoid
-	 * reloading the GObject types.
-	 */
-	CallNPN_SetValueProc (sNPN.setvalue,
-			      mInstance,
-			      NPPVpluginKeepLibraryInMemory,
-			      NS_INT32_TO_PTR (PR_TRUE));
-
 	/* mode is NP_EMBED, NP_FULL, or NP_BACKGROUND (see npapi.h) */
 	/* FIXME we should error out if we are in fullscreen mode
 	 * FIXME: This might be possible on gecko trunk by returning an
@@ -1636,14 +1639,19 @@ totemPlugin::Init (NPMIMEType mimetype,
 	D ("Real mimetype for '%s' is '%s'", mimetype, mMimeType.get());
 
 	/* Now parse the attributes */
+	/* Note: argv[i] is NULL for the "PARAM" arg which separates the attributes
+	 * of an <object> tag from the <param> values under it.
+	 */
 	GHashTable *args = g_hash_table_new_full (g_str_hash,
 		g_str_equal,
 		(GDestroyNotify) g_free,
 		(GDestroyNotify) g_free);
 	for (int16_t i = 0; i < argc; i++) {
-		printf ("argv[%d] %s %s\n", i, argn[i], argv[i]);
-		g_hash_table_insert (args, g_ascii_strdown (argn[i], -1),
-				     g_strdup (argv[i]));
+		printf ("argv[%d] %s %s\n", i, argn[i], argv[i] ? argv[i] : "");
+		if (argv[i]) {
+			g_hash_table_insert (args, g_ascii_strdown (argn[i], -1),
+					     g_strdup (argv[i]));
+		}
 	}
 
 	const char *value;
@@ -1763,6 +1771,8 @@ totemPlugin::Init (NPMIMEType mimetype,
 
 	mControllerHidden = !GetBooleanValue (args, "controller", PR_TRUE);
 
+	mAutoPlay = GetBooleanValue (args, "autoplay", PR_TRUE);
+
 #endif /* TOTEM_NARROWSPACE_PLUGIN */
 
 #if defined(TOTEM_COMPLEX_PLUGIN) && defined(HAVE_NSTARRAY_H)
@@ -1837,7 +1847,7 @@ totemPlugin::Init (NPMIMEType mimetype,
 #ifdef TOTEM_NARROWSPACE_PLUGIN
 	/* We need to autostart if we're using an HREF
 	 * otherwise the start image isn't shown */
-	if (!mHref.Equals (NS_LITERAL_CSTRING (""))) {
+	if (!mHref.IsEmpty ()) {
 		mExpectingStream = PR_TRUE;
 		mAutostart = PR_TRUE;
 	}
