@@ -7,8 +7,6 @@
 #include <libintl.h>
 
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
-#include <X11/Xlib.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
@@ -213,10 +211,24 @@ totem_time_to_string (gint64 msecs)
 	if (hour > 0)
 	{
 		/* hour:minutes:seconds */
-		return g_strdup_printf ("%d:%02d:%02d", hour, min, sec);
+		/* Translators: This is a time format, like "9:05:02" for 9
+		 * hours, 5 minutes, and 2 seconds. You may change ":" to
+		 * the separator that your locale uses or use "%Id" instead
+		 * of "%d" if your locale uses localized digits. Do not
+		 * translate the "long time format|" part. Remove it from
+		 * the translation.
+		 */
+		return g_strdup_printf (Q_("long time format|%d:%02d:%02d"), hour, min, sec);
 	} else {
 		/* minutes:seconds */
-		return g_strdup_printf ("%d:%02d", min, sec);
+		/* Translators: This is a time format, like "5:02" for 5
+		 * minutes and 2 seconds. You may change ":" to the
+		 * separator that your locale uses or use "%Id" instead of
+		 * "%d" if your locale uses localized digits. Do not
+		 * translate the "short time format|" part. Remove it from
+		 * the translation.
+		 */
+		return g_strdup_printf (Q_("short time format|%d:%02d"), min, sec);
 	}
 
 	return NULL;
@@ -315,6 +327,7 @@ totem_ratio_fits_screen (GdkWindow *video_window, int video_width,
 {
 	GdkRectangle fullscreen_rect;
 	int new_w, new_h;
+	GdkScreen *screen;
 
 	if (video_width <= 0 || video_height <= 0)
 		return TRUE;
@@ -322,10 +335,10 @@ totem_ratio_fits_screen (GdkWindow *video_window, int video_width,
 	new_w = video_width * ratio;
 	new_h = video_height * ratio;
 
-	gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
+	screen = gdk_drawable_get_screen (GDK_DRAWABLE (video_window));
+	gdk_screen_get_monitor_geometry (screen,
 			gdk_screen_get_monitor_at_window
-			(gdk_screen_get_default (),
-			 video_window),
+			(screen, video_window),
 			&fullscreen_rect);
 
 	if (new_w > (fullscreen_rect.width - 128) ||
