@@ -704,13 +704,6 @@ totem_pl_parser_finalize (GObject *object)
 	G_OBJECT_CLASS (totem_pl_parser_parent_class)->finalize (object);
 }
 
-//FIXME remove ?
-static gboolean
-totem_pl_parser_check_utf8 (const char *title)
-{
-	return title ? g_utf8_validate (title, -1, NULL) : FALSE;
-}
-
 static void
 totem_pl_parser_add_url_valist (TotemPlParser *parser,
 				const gchar *first_property_name,
@@ -856,6 +849,7 @@ static PlaylistTypes special_types[] = {
 static PlaylistTypes dual_types[] = {
 	PLAYLIST_TYPE2 ("audio/x-real-audio", totem_pl_parser_add_ra, totem_pl_parser_is_uri_list),
 	PLAYLIST_TYPE2 ("audio/x-pn-realaudio", totem_pl_parser_add_ra, totem_pl_parser_is_uri_list),
+	PLAYLIST_TYPE2 ("application/ram", totem_pl_parser_add_ra, totem_pl_parser_is_uri_list),
 	PLAYLIST_TYPE2 ("application/vnd.rn-realmedia", totem_pl_parser_add_ra, totem_pl_parser_is_uri_list),
 	PLAYLIST_TYPE2 ("audio/x-pn-realaudio-plugin", totem_pl_parser_add_ra, totem_pl_parser_is_uri_list),
 	PLAYLIST_TYPE2 ("audio/vnd.rn-realaudio", totem_pl_parser_add_ra, totem_pl_parser_is_uri_list),
@@ -897,6 +891,7 @@ totem_pl_parser_scheme_is_ignored (TotemPlParser *parser, const char *url)
 	return FALSE;
 }
 
+//FIXME remove ?
 static gboolean
 totem_pl_parser_mimetype_is_ignored (TotemPlParser *parser,
 				     const char *mimetype)
